/**
  *  \file client/dialogs/fleetcost.h
  *  \brief Simulator Fleet Cost Comparison
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_DIALOGS_FLEETCOST_H
#define PCC_V2_CLIENT_DIALOGS_FLEETCOST_H

#include "ui/window.h"
#include "game/playerset.h"
#include "cpluslib/holder.h"
#include "client/widgets/billdisplay.h"

class GSimState;
class WBillDisplay;
class WBillTotalDisplay;
class UIScrollbar;

/* FIXME: move this elsewhere and merge with other instances of the same idea */
class WFlexibleText : public UIWidget {
    string_t str;
 public:
    WFlexibleText();
    void getLayoutInfo(LayoutInfo& info);
    void drawContent(GfxCanvas& can);
    void setText(string_t what);
};

class WFleetCostDialog : public UIWindow {
    ObjectHolder h;
    const GSimState& state;
    GPlayerSet available_players;
    GPlayerSet available_teams;
    int current_player;
    int current_team;

    WBill fleet_cost;

    WBillDisplay* bill_dpy;
    WBillTotalDisplay* total_dpy;
    UIScrollbar* scrollbar;
    WFlexibleText* race_dpy;

    void init();
    void browse(int delta);
    bool isVisibleOwner(int pl) const;
    void generateSummary();
 public:
    WFleetCostDialog(const GSimState& state);
    ~WFleetCostDialog();
    bool handleEvent(const UIEvent& event, bool second_pass);
};

#endif
