 /**
  *  \file vcrplay.h
  *  \brief VCR Player (GUI)
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_VCRPLAY_H
#define PCC_V2_VCRPLAY_H

#include "cpluslib/smartptr.h"
#include "cpluslib/call.h"
#include "ui/ui.h"
#include "game/vcr.h"
#include "game/vcrdb.h"
#include "ui/commands.h"
#include "ui/window.h"
#include "ui/widgets/button.h"

class GClassicVcrDatabase;
class GClassicVcrEntry;

/** VCR Selector Widget. */
class WVcrSelector : public UIWidget {
    int index;                  /**< Currently displayed battle. Range is [0, db->getVcrCount()) */
    GClassicVcrDatabase& db;    /**< VCR Database to play. */
    GClassicVcrEntry* entry;    /**< Current database entry. Equals db->getEntry(index). */
    Ptr<VcrPlayer> player;      /**< VCR Player to use. Non-null while computing, otherwise 0. */
    int disp_status;            /**< Displayed status. 0 if battle ending not known, nonzero else. */
    bool playing;

    UIButton btn_l;
    UIButton btn_r;
    UIButton btn_tab;

    void drawWarrior(GfxContext& ctx, int x, int y, int w, int side);
    void drawStatus(GfxContext& ctx);
    void maybeRestartPlayer();
 public:
    WVcrSelector(GClassicVcrDatabase& adb);
    ~WVcrSelector();

    void selectVcr(int aindex);
    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo&);
    int getCurrentVcr() const
        { return index; }
    GClassicVcrDatabase& getCurrentDatabase()
        { return db; }

    bool handleEvent(const UIEvent& e, bool second_pass);
    void onResize(GfxRect oldsize, bool by_layout);

    /* slots */
    void playIt();
    void next();
    void prev();
    void diagram();
};

class WVcrSelectorWindowGameInterface : public Object {
 public:
    /** Check whether the specified object is a game object. */
    virtual bool isGameObject(const GVcrObject& obj) = 0;

    /** Schedule going to the specified game object.
        (The WVcrSelectorWindow will close, caller must then execute the request.) */
    virtual void goToGameObject(const GVcrObject& obj) = 0;
};

class WVcrSelectorWindow : public UIWindow {
    WVcrSelector& sel;
    WVcrSelectorWindowGameInterface& gameif;
 public:
    WVcrSelectorWindow(WVcrSelector& sel, WVcrSelectorWindowGameInterface& gameif);
    ~WVcrSelectorWindow();

    bool handleEvent(const UIEvent& event, bool second_pass);
};

#endif
