/**
  *  \file u/t_io_streams.cc
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "io/streams.h"
#include "io/memstream.h"
#include "u/t_io.h"

static void
testRead(Stream& s, const char* expect)
{
    while (*expect) {
        char c;
        int n = s.read(&c, 1);
        TS_ASSERT_EQUALS(n, 1);
        TS_ASSERT_EQUALS(c, *expect);
        ++expect;
    }
}

void
IoStreamsTestSuite::testStreams()
{
    Ptr<MemoryStream> ms = new MemoryStream("The quick brown fox jumps over the lazy dog");
    ms->seek(0);
    testRead(*ms, "The quick brown fox");

    Ptr<Stream> dup1 = new ChildStream(*ms);
    Ptr<Stream> dup2 = new ChildStream(*ms);

    dup1->seek(0);
    dup2->seek(0);
    testRead(*dup1, "The quick brown fox");
    testRead(*dup2, "The quick brown fox");
    testRead(*dup1, " jumps over");
    testRead(*dup2, " jumps over the lazy");
    testRead(*dup1, " the lazy");

    ms = 0;
    dup1 = 0;
    dup2 = 0;
}
